==> ms_fabric_cli-0.1.10-py3-none-any.whl: fabric_cli/commands/fs/ls/fab_fs_ls_externaldatashare.py <==
# Copyright (c) Microsoft Corporation.
# Licensed under the EULA license.

from fabric_cli.core.fab_hiearchy import VirtualItemContainer
from fabric_cli.utils import fab_mem_store as utils_mem_store
from fabric_cli.utils import fab_ui as utils_ui
from fabric_cli.utils import fab_util as utils


def exec(vic: VirtualItemContainer, args, show_details):
    external_data_shares = utils_mem_store.get_external_data_shares(vic.get_parent())

    if external_data_shares:
        sorted_external_data_shares = sorted(
            [
                {
                    "name": eds.get_name(),
                    "id": eds.get_id(),
                    "status": eds.get_status(),
                    "itemId": eds.get_item_id(),
                }
                for eds in external_data_shares
            ],
            key=lambda item: item["name"],
        )

        base_cols = ["name"]

        should_filter_out_revoked_eds = not show_details
        if show_details:
            eds_detail_cols = [
                "id",
                "status",
                "itemId",
                # "creatorPrincipal",
                # "expirationTimeUtc",
                # "invitationUrl",
                # "paths",
                # "recipient",
                # "workspaceId",
            ]
            eds_detail_col_enrich = "itemName"

            for external_data_share in sorted_external_data_shares:
                item_name = utils.get_item_name_from_eds_name(
                    external_data_share.get("name")
                )
                external_data_share[eds_detail_col_enrich] = item_name

        if should_filter_out_revoked_eds:
            sorted_external_data_shares = [
                eds
                for eds in sorted_external_data_shares
                if not eds["status"] == "Revoked"
            ]

        columns = (
            base_cols + eds_detail_cols + [eds_detail_col_enrich]
            if show_details
            else base_cols
        )
        utils_ui.print_entries_unix_style(
            sorted_external_data_shares, columns, header=show_details
        )

==> ms_fabric_cli-1.0.0-py3-none-any.whl: fabric_cli/commands/fs/ls/fab_fs_ls_externaldatashare.py <==
# Copyright (c) Microsoft Corporation.
# Licensed under the EULA license.

from fabric_cli.core.hiearchy.fab_hiearchy import VirtualItemContainer
from fabric_cli.utils import fab_mem_store as utils_mem_store
from fabric_cli.utils import fab_ui as utils_ui
from fabric_cli.utils import fab_util as utils


def exec(vic: VirtualItemContainer, args, show_details):
    external_data_shares = utils_mem_store.get_external_data_shares(vic.parent)

    if external_data_shares:
        sorted_external_data_shares = sorted(
            [
                {
                    "name": eds.name,
                    "id": eds.id,
                    "status": eds.status,
                    "itemId": eds.item_id,
                }
                for eds in external_data_shares
            ],
            key=lambda item: item["name"],
        )

        base_cols = ["name"]

        should_filter_out_revoked_eds = not show_details
        if show_details:
            eds_detail_cols = [
                "id",
                "status",
                "itemId",
                # "creatorPrincipal",
                # "expirationTimeUtc",
                # "invitationUrl",
                # "paths",
                # "recipient",
                # "workspaceId",
            ]
            eds_detail_col_enrich = "itemName"

            for external_data_share in sorted_external_data_shares:
                item_name = utils.get_item_name_from_eds_name(
                    external_data_share.get("name")
                )
                external_data_share[eds_detail_col_enrich] = item_name

        if should_filter_out_revoked_eds:
            sorted_external_data_shares = [
                eds
                for eds in sorted_external_data_shares
                if not eds["status"] == "Revoked"
            ]

        columns = (
            base_cols + eds_detail_cols + [eds_detail_col_enrich]
            if show_details
            else base_cols
        )
        utils_ui.print_entries_unix_style(
            sorted_external_data_shares, columns, header=show_details
        )
